pub type UnitCompletion = SyncCompletion<()>;Expand description
Completion for operations that return only success or an error.
Aliased Type
pub struct UnitCompletion { /* private fields */ }pub type UnitCompletion = SyncCompletion<()>;Completion for operations that return only success or an error.
pub struct UnitCompletion { /* private fields */ }